summaryrefslogtreecommitdiff
path: root/telepathy-glib/channel-request.c
diff options
context:
space:
mode:
authorSimon McVittie <simon.mcvittie@collabora.co.uk>2012-05-02 19:06:24 +0100
committerSimon McVittie <simon.mcvittie@collabora.co.uk>2012-05-02 20:19:36 +0100
commit9aec808ae99f5b06c816943fc1648358af0d8294 (patch)
treeac7f5cd918ca45932fd321648e9f589d35e966c2 /telepathy-glib/channel-request.c
parent2cc2520bcfa36c834dab111ebf41637bbfc8371f (diff)
downloadtelepathy-glib-9aec808ae99f5b06c816943fc1648358af0d8294.tar.gz
Stop using TP_ERRORS
We deprecated this in 0.11.
Diffstat (limited to 'telepathy-glib/channel-request.c')
-rw-r--r--telepathy-glib/channel-request.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/telepathy-glib/channel-request.c b/telepathy-glib/channel-request.c
index 08fcf1f9c..636456ab1 100644
--- a/telepathy-glib/channel-request.c
+++ b/telepathy-glib/channel-request.c
@@ -72,7 +72,7 @@
* indicates that the channel request no longer exists).
*
* On failure, the #TpProxy::invalidated signal will be emitted with some
* other suitable error, usually from the %TP_ERRORS domain.
*
* If the channel dispatcher crashes or exits, the #TpProxy::invalidated
* signal will be emitted with the domain %TP_DBUS_ERRORS and the error code
@@ -544,7 +544,7 @@ tp_channel_request_init_known_interfaces (void)
tp_proxy_or_subclass_hook_on_interface_add (tp_type,
tp_cli_channel_request_add_signals);
tp_proxy_subclass_add_error_mapping (tp_type,
- TP_ERROR_PREFIX, TP_ERRORS, TP_TYPE_ERROR);
+ TP_ERROR_PREFIX, TP_ERROR, TP_TYPE_ERROR);
g_once_init_leave (&once, 1);
}
@@ -72,7 +72,7 @@
*
* On failure, the #TpProxy::invalidated signal will be emitted with some
- * other suitable error, usually from the %TP_ERRORS domain.
+ * other suitable error, usually from the %TP_ERROR domain.
*
* If the channel dispatcher crashes or exits, the #TpProxy::invalidated